﻿<?xml version="1.0" encoding="utf-8"?>
<pattern id="Content" xmlns="http://purl.oclc.org/dsdl/schematron">
    <title>Content Validations</title>

  <rule context="xbrli:xbrl[not(@i:nil='true')]">
    
    <!-- Rule ID: VR.ATO.ODRPT.000010
         ELS Ref: V35

         IF ([odrpt5] <> NULLORBLANK) AND ([odrpt5] <> SET("Income Tax Client Report", "Activity Statement Client Report", "Activity Statement Lodgment Report"))
           RETURN VALIDATION MESSAGE
         ENDIF  
                
		     [mrpts2] = pyin.xx.xx:Report.Type.Code
    -->
    <assert id="VR.ATO.ODRPT.000010" diagnostics="DVR.ATO.ODRPT.000010"
          test="not(
                      $odrpt5[
                                not(@i:nil='true') and string-length(.) != 0
                                and
                                . != 'Income Tax Client Report'
                                and
                                . != 'Income Tax Client Report v2'
                                and
                                . != 'Activity Statement Client Report'
                                and
                                . != 'Activity Statement Lodgment Report'
                                and
                                . != 'Activity Statement Lodgment Report v2'
                             ]
                     )"/>
    
  </rule>
  
  <!-- LOOP THROUGH REPORTING PARTY SEQUENCE CONTEXTS -->
  <rule context="xbrli:xbrl/xbrli:context[@id = $RPCLISEQ.ContextId]">

    <let name="thisContextId" value="@id" />
    
    <!-- Rule ID: VR.ATO.ODRPT.000004
         ELS Ref: V1200

		     IF ANY OCCURRENCE OF (([odrpt3] <> NULLORBLANK) AND (ABNALGORITHM([odrpt3]) = FALSE))
           RETURN VALIDATION MESSAGE
         ENDIF

		     [odrpt3] = pyid.xx.xx:Identifiers.AustralianBusinessNumber.Identifier
    -->
    <assert id="VR.ATO.ODRPT.000004" diagnostics="DVR.ATO.ODRPT.000004"
          test="not(
                      $odrpt3[
                                not(@i:nil='true') and string-length(.) != 0
                                and
                                not(function:ValidateABN(.)) 
                                and
                                @contextRef = $thisContextId
                             ]
                     )"/>
    
    
    <!-- Rule ID: VR.ATO.ODRPT.000005
         ELS Ref: V1200

		     IF ANY OCCURRENCE OF (([odrpt4] <> NULLORBLANK) AND (TFNALGORITHM ([odrpt4]) = FALSE))
           RETURN VALIDATION MESSAGE
         ENDIF

		     [odrpt4] = pyid.xx.xx:Identifiers.TaxFileNumber.Identifier
    -->
    <assert id="VR.ATO.ODRPT.000005" diagnostics="DVR.ATO.ODRPT.000005"
          test="not(
                      $odrpt4[
                                not(@i:nil='true') and string-length(.) != 0
                                and
                                not(function:ValidateTFN(.)) 
                                and
                                @contextRef = $thisContextId
                             ]
                     )"/>
    
    
    <!-- Rule ID: VR.ATO.ODRPT.000011
         ELS Ref: V35

		     IF (
              [odrpt2] = FALSE 
              AND 
              (
                (
                  [odrpt3] = NULLORBLANK 
                  AND 
                  [odrpt4] = NULLORBLANK
                ) 
                OR 
                (
                  [odrpt3] <> NULLORBLANK 
                  AND 
                  [odrpt4] <> NULLORBLANK
                )
              )
            )
           RETURN VALIDATION MESSAGE
         ENDIF

		     [odrpt2] = pyde.xx.xx:OrganisationDetails.WholeOfPractice.Indicator
		     [odrpt3] = pyid.xx.xx:Identifiers.AustralianBusinessNumber.Identifier
		     [odrpt4] = pyid.xx.xx:Identifiers.TaxFileNumber.Identifier
    -->
    <assert id="VR.ATO.ODRPT.000011" diagnostics="DVR.ATO.ODRPT.000011"
          test="not(
                      $odrpt2[matches(.,'^(false|0)$')]
                      and
                      (
                        (
                          not($odrpt3[not(@i:nil='true') and string-length(.) != 0 and @contextRef = $thisContextId])
                          and 
                          not($odrpt4[not(@i:nil='true') and string-length(.) != 0 and @contextRef = $thisContextId])
                        )
                        or
                        (
                          $odrpt3[not(@i:nil='true') and string-length(.) != 0 and @contextRef = $thisContextId]
                          and 
                          $odrpt4[not(@i:nil='true') and string-length(.) != 0 and @contextRef = $thisContextId]
                        )
                      )
                    )"/>

        <!-- Rule ID: VR.ATO.ODRPT.000012
             ELS Ref: N/A

		        IF ([odrpt2] = TRUE AND ([odrpt3] <> NULLORBLANK OR [odrpt4] <> NULLORBLANK))
		           RETURN VALIDATION MESSAGE
		        ENDIF

		        [odrpt2] = pyde.xx.xx:OrganisationDetails.WholeOfPractice.Indicator
		        [odrpt3] = pyid.xx.xx:Identifiers.AustralianBusinessNumber.Identifier
		        [odrpt4] = pyid.xx.xx:Identifiers.TaxFileNumber.Identifier
        -->
    <assert id="VR.ATO.ODRPT.000012" diagnostics="DVR.ATO.ODRPT.000012"
          test="not(
                      $odrpt2[matches(.,'^(true|1)$')]
                      and
                      (
                          $odrpt3[not(@i:nil='true') and string-length(.) != 0 and @contextRef = $thisContextId]
                          or
                          $odrpt4[not(@i:nil='true') and string-length(.) != 0 and @contextRef = $thisContextId]
                      )
                    )"/>

        <!-- Rule ID: VR.ATO.ODRPT.000013
            ELS Ref: N/A

		        IF ([odrpt5] <> NULLORBLANK) AND [odrpt5] = SET("Income Tax Client Report", "Activity Statement Lodgment Report") AND DATE(TODAY) > '2024-12-01'
		            RETURN VALIDATION MESSAGE
		        ENDIF

		        [odrpt5] = ODRPT:RP:pyin.02.02:Report.Type.Code
        -->
    <assert id="VR.ATO.ODRPT.000013" diagnostics="DVR.ATO.ODRPT.000013"
          test="not(
                  $odrpt5[
                    . = 'Income Tax Client Report'
                    or
                    . = 'Activity Statement Lodgment Report'
                  ]
                  and
                  function:IsDate1GreaterThanDate2(current-date(), '2024-12-01')
                )"/>
    
  </rule>
</pattern>